@@ -19,8 +19,17 @@ from typedpy.fields import (
     Integer,
     PositiveInt,
     PositiveFloat,
+    NonPositiveInt,
+    NonPositiveFloat,
+    NegativeInt,
+    NegativeFloat,
+    NonNegativeInt,
+    NonNegativeFloat,
     Float,
     Positive,
+    Negative,
+    NonPositive,
+    NonNegative,
     DecimalNumber,
     String,
     SizedString,
